@@ -1,7 +1,9 @@
+import json
 from typing import Any, TYPE_CHECKING
 
 from bclib.listener.http_listener import HttpBaseDataName, HttpBaseDataType
 from bclib.utility import DictEx, HttpStatusCodes, HttpMimeTypes, ResponseTypes
+from bclib.exception import ShortCircuitErr
 from ..context.context import Context
 
 if TYPE_CHECKING:
@@ -18,8 +20,8 @@ class RequestContext(Context):
         self.query: DictEx = self.cms.query
         self.form: DictEx = self.cms.form
         self.__headers: dict = None
-        self.response_type: ResponseTypes = ResponseTypes.RENDERED
-        self.status_code: HttpStatusCodes = HttpStatusCodes.OK
+        self.response_type: str = ResponseTypes.RENDERED
+        self.status_code: str = HttpStatusCodes.OK
         self.mime = HttpMimeTypes.HTML
 
     def add_header(self, key: str, value: str) -> None:
@@ -35,31 +37,35 @@ class RequestContext(Context):
     def generate_error_response(self, exception: Exception) -> dict:
         """Generate error response from process result"""
         error_object, self.status_code = self._generate_error_object(exception)
-        content = f"{error_object['errorMessage']} (Error Code: {error_object['errorCode']})"
-        if 'error' in error_object:
-            error = error_object["error"].replace("\n", "</br>")
-            content += f"<hr/>{error}"
+        if isinstance(exception, ShortCircuitErr) and exception.data:
+            content = exception.data if isinstance(
+                exception.data, str) else json.dumps(exception.data, indent=1).replace("\n", "</br>")
+        else:
+            content = f"{error_object['errorMessage']} (Error Code: {error_object['errorCode']})"
+            if 'error' in error_object:
+                error = error_object["error"].replace("\n", "</br>")
+                content += f"<hr/>{error}"
         return self.generate_response(content)
 
     def generate_response(self, result: Any) -> dict:
         """Generate response from process result"""
 
         ret_val = self.cms
-        ret_val[HttpBaseDataType.CMS][HttpBaseDataName.WEB_SERVER] = {
-            "index": self.response_type.value,
-            "headercode": self.status_code.value,
-            "mime": self.mime
-        }
+        if HttpBaseDataType.CMS not in ret_val:
+            ret_val[HttpBaseDataType.CMS] = {}
+        if HttpBaseDataName.WEB_SERVER not in ret_val[HttpBaseDataType.CMS]:
+            ret_val[HttpBaseDataType.CMS][HttpBaseDataName.WEB_SERVER] = DictEx()
+        ret_val[HttpBaseDataType.CMS][HttpBaseDataName.WEB_SERVER]["index"] = self.response_type
+        ret_val[HttpBaseDataType.CMS][HttpBaseDataName.WEB_SERVER]["headercode"] = self.status_code
+        ret_val[HttpBaseDataType.CMS][HttpBaseDataName.WEB_SERVER]["mime"] = self.mime
         if self.__headers is not None:
             RequestContext.__add_user_defined_headers(ret_val, self.__headers)
         return ret_val
 
-    @staticmethod
+    @ staticmethod
     def __add_user_defined_headers(response: dict, headers: dict) -> None:
         """Adding user defined header to response"""
 
-        if HttpBaseDataType.CMS not in response:
-            response[HttpBaseDataType.CMS] = {}
         if HttpBaseDataName.HTTP not in response[HttpBaseDataType.CMS]:
             response[HttpBaseDataType.CMS][HttpBaseDataName.HTTP] = {}
         http = response[HttpBaseDataType.CMS][HttpBaseDataName.HTTP]
