@@ -1,13 +1,14 @@
 import asyncio
+import inspect
 import json
 import re
 from struct import error
-from typing import Callable, Any
+from typing import Callable, Any, Coroutine
 from abc import abstractmethod
 
 from bclib.utility import DictEx
 
-from bclib.context import ClientSourceContext, RESTfulContext, WebContext, RequestContext, Context, SocketContext, ServerSourceContext
+from bclib.context import ClientSourceContext, RESTfulContext, WebContext, RequestContext, Context, SocketContext, ServerSourceContext, NamedPipeContext
 from bclib.listener import Message, MessageType, HttpBaseDataType
 
 from ..dispatcher.dispatcher_helper import DispatcherHelper
@@ -21,7 +22,8 @@ class RoutingDispatcher(Dispatcher, DispatcherHelper):
         self.__default_router = self.options.defaultRouter\
             if 'defaultRouter' in self.options and isinstance(self.options.defaultRouter, str)\
             else None
-
+        self.name = self.options["name"] if self.options.has("name") else None
+        self.__log_name = f"{self.name}: " if self.name else ''
         if self.options.has('router'):
             router = self.options.router
             if isinstance(router, str):
@@ -63,9 +65,9 @@ class RoutingDispatcher(Dispatcher, DispatcherHelper):
         context_type: str = None
         if url:
             try:
-                for pattern, lookup_conyext_type in self.__context_type_lookup:
+                for pattern, lookup_context_type in self.__context_type_lookup:
                     if pattern == "*" or re.search(pattern, url):
-                        context_type = lookup_conyext_type
+                        context_type = lookup_context_type
                         break
             except TypeError:
                 pass
@@ -84,7 +86,7 @@ class RoutingDispatcher(Dispatcher, DispatcherHelper):
                 message_result = json.dumps(response).encode("utf-8")
                 ret_val = Message.create_add_hock(
                     message.session_id, message_result)
-                await self.send_message_async(ret_val)
+                # await self.send_message_async(ret_val)
             return ret_val
         except error as ex:
             print(f"Error in process received message {ex}")
@@ -118,7 +120,7 @@ class RoutingDispatcher(Dispatcher, DispatcherHelper):
             context_type = "socket"
         if self.log_request:
             print(
-                f"({context_type}::{message.type.name}){f' : {request_id} {method} {url} ' if cms_object else ''}")
+                f"{self.__log_name}({context_type}::{message.type.name}){f' - {request_id} {method} {url} ' if cms_object else ''}")
 
         if context_type == "client_source":
             ret_val = ClientSourceContext(cms_object, self)
@@ -130,6 +132,8 @@ class RoutingDispatcher(Dispatcher, DispatcherHelper):
             ret_val = WebContext(cms_object, self)
         elif context_type == "socket":
             ret_val = SocketContext(cms_object, self, message, message_json)
+        elif context_type == "named_pipe":
+            ret_val = NamedPipeContext(message_json, message_string, self)
         elif context_type is None:
             raise Exception(f"No context found for '{url}'")
         else:
@@ -137,11 +141,13 @@ class RoutingDispatcher(Dispatcher, DispatcherHelper):
                 f"Configured context type '{context_type}' not found for '{url}'")
         return ret_val
 
-    def run_in_background(self, callback: Callable, *args: Any) -> asyncio.Future:
+    def run_in_background(self, callback: 'Callable|Coroutine', *args: Any) -> asyncio.Future:
         """helper for run function in background thread"""
 
-        loop = asyncio.get_running_loop()
-        return loop.run_in_executor(None, callback, *args)
+        if inspect.iscoroutinefunction(callback):
+            return self.event_loop.create_task(callback(*args))
+        else:
+            return self.event_loop.run_in_executor(None, callback, *args)
 
     @abstractmethod
     async def send_message_async(self, message: MessageType) -> bool:
