@@ -1,3 +1,3 @@
 from bclib.parser.answer.answer import Answer
-from bclib.parser.answer.user_action_type import UserActionType
+from bclib.parser.answer.user_action_types import UserActionTypes
 from bclib.parser.answer.user_action import UserAction
