@@ -3,3 +3,5 @@ from bclib.utility.http_status_codes import HttpStatusCodes
 from bclib.utility.http_mime_types import HttpMimeTypes
 from bclib.utility.response_types import ResponseTypes
 from bclib.utility.http_headers import HttpHeaders
+from bclib.utility.windows_named_pipe_helper import WindowsNamedPipeHelper
+from bclib.utility.linux_named_pipe_helper import LinuxNamedPipeHelper
